@@ -5,7 +5,9 @@ package MarpaX::Languages::ECMAScript::AST::Grammar::ECMAScript_262_5::Program::
 
 # ABSTRACT: ECMAScript 262, Edition 5, lexical expressions grammar actions
 
-our $VERSION = '0.001'; # TRIAL VERSION
+our $VERSION = '0.002'; # TRIAL VERSION
+
+use constant AST => 'MarpaX::Languages::ECMAScript::AST';
 
 
 
@@ -17,6 +19,24 @@ sub new {
 }
 
 
+sub DecimalLiteral {
+    my $self = shift;
+    return bless(shift, AST . '::DecimalLiteral');
+}
+
+
+sub HexIntegerLiteral {
+    my $self = shift;
+    return bless(shift, AST . '::HexIntegerLiteral');
+}
+
+
+sub OctalIntegerLiteral {
+    my $self = shift;
+    return bless(shift, AST . '::OctalIntegerLiteral');
+}
+
+
 sub concat {
     my $self = shift;
 
@@ -37,7 +57,7 @@ MarpaX::Languages::ECMAScript::AST::Grammar::ECMAScript_262_5::Program::Actions
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 DESCRIPTION
 
@@ -47,6 +67,18 @@ This modules give the actions associated to ECMAScript_262_5 lexical expressions
 
 Instantiate a new object.
 
+=head2 DecimalLiteral($self, $lexeme)
+
+Bless lexeme to a DecimalLiteral.
+
+=head2 HexIntegerLiteral($self, $lexeme)
+
+Bless lexeme to a HexIntegerLiteral.
+
+=head2 OctalIntegerLiteral($self, $lexeme)
+
+Bless lexeme to a OctalIntegerLiteral.
+
 =head2 concat($self)
 
 Concatenate arguments. Use for tests.
